package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jun 30, 2026
License: MIT
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package httpmw provides net/http middleware for request-id propagation and
access logging. It also covers chi, which uses the stdlib signature.
Middleware returns net/http middleware that injects a request-scoped logger
and emits one access-log entry per request.
type Option func(*config)
Option configures the middleware.
WithGenerator overrides the request-id generator.
WithHeader overrides the request-id header name.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.